virtualenv_install_stanza: Install Stanza via Virtual Environment

View source: R/install.R

virtualenv_install_stanzaR Documentation

Install Stanza via Virtual Environment

Description

Install Stanza via Virtual Environment

Usage

virtualenv_install_stanza(
  envname = "stanza",
  packages = "stanza",
  python = NULL,
  ...
)

Arguments

envname

a character string giving the name or path of the virtual environment to be used or created for the installation.

packages

a character vector giving the packages to be installed.

python

a string giving the name or path of the python version to be used (e.g., "python3").

...

additional arguments passed to conda_install.

Value

NULL

Examples

## Not run: 
virtualenv_install_stanza()

## End(Not run)

stanza documentation built on June 8, 2025, 1:23 p.m.