| virtualenv_install_stanza | R Documentation |
Install Stanza via Virtual Environment
virtualenv_install_stanza(
envname = "stanza",
packages = "stanza",
python = NULL,
...
)
envname |
a character string giving the name or path of the virtual environment to be used or created for the installation. |
packages |
a character vector giving the packages to be installed. |
python |
a string giving the name or path of the python version to be used
(e.g., |
... |
additional arguments passed to |
NULL
## Not run:
virtualenv_install_stanza()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.